"""
Helper for notebook setup that can re-create the entire `room` and
`solar_system` directories.
"""

import os

ROOM_LAYOUT = {
    'room/charger.txt': """\
This is a worn cellphone charger, plugged into a wall outlet. It's sort
of awkwardly placed, but it reaches to the corner of the desk, at least.
""",
    'room/bed/sheets.txt': """\
Your sheets and covers aren't just crumpled in a ball but they're not
exactly neat either. Sleep hasn't been at the top of your priority list
these days so you're often rushing out in the mornings.
""",

    'room/closet/clothes.txt': """\
Your shirts and dresses hang up in the closet, probably the most
organized part of your wardrobe (except the two that have migrated to the
closet floor).
""",
    'room/closet/scooter.txt': """\
Here's where you keep your scooter out of the way when you're not using
it. The weather has been too cold and wet lately for you to want to use
it, but now that Spring is finally kicking into gear, you'll be zooming
around campus more easily soon you hope.
""",

    'room/desk/laptop.txt': """\
When you're not carrying it around somewhere, your laptop tends to
gravitate to the desk, where you spend much of your time on homework,
games, social media, and all the other incessant digital follies of the
modern world. Your phone gets used for a lot of that stuff too, but
sometimes a bigger screen and a keyboard is nice. Thankfully the charger
just reaches the nearby wall outlet.
""",
    'room/desk/sculpture.txt': """\
A wire sculpture sits on your desk, given to you by a good friend. It
depicts a flock of birds flying together, and balances on a weighted base.
""",

    'room/desk/drawer/documents.txt': """\
Here's where you keep your passport and other important documents, like
that expired ice cream gift card you were saving for a warm day and
tragically forgot (maybe you should actually throw it out?).
""",

    'room/dresser/pile.txt': """\
Some clothes just go in a pile on the dresser. They fit there so
naturally it would be a shame to clean them up, really. Besides, if they
were in a drawer or the closet you'd have to hunt for them.
""",

    'room/dresser/drawer1/book.txt': """\
A sci-fi paperback somehow made its way into this drawer, and you
occasionally read a bit more when you're bored, but it didn't really grab
your interest which is why it's been stuffed in here for some time.
You're pretty sure it's not a library book.
""",
    'room/dresser/drawer1/clothes.txt': """\
This top drawer is full of underwear and socks, plus a few t-shirts that
wandered in somehow.
""",

    'room/dresser/drawer2/clothes.txt': """\
This bottom drawer is full of pants and skirts. The uglier ones are
neatly folded at the bottom because they don't get used much while your
favorites are piled on top.
""",

    'room/nightstand/lamp.txt': """\
You have a small lamp on top of your nightstand which is nice because you
can turn it off when you're already in bed. Half the time you don't
bother to turn it on and just read stuff on your phone without another
light, even though you know it's bad for your sleep. At least you did
enable bedtime mode to reduce the blue wavelengths.
""",

    'room/nightstand/bottom_drawer/cosmetics.txt': """\
You don't know why you keep this stuff down here. It's always a bit
awkward to get out and put away, and you use it every day... but people
are just weird sometimes. Maybe it's a leftover habit from when you had
to share your bathroom with your little brother?
""",
    'room/nightstand/bottom_drawer/rock.txt': """\
Your pet rock, complete with adorable googly eyes. You've had it since
you were a teenager and as time goes on you're more and more convinced it
will be a lifelong companion. Its faintly encouraging smile has never
judged you, and you've only had to glue the eyes back on a few times.
""",

    'room/nightstand/top_drawer/journal.txt': """\
If this were a videogame this journal would reveal some key secrets about
your life and history. But instead, it's something you bought on a whim
but never really kept up with. There's one entry where you inexplicably
wrote about seeing some birds (which is like, something that happens
every single day?!?) and then it's just blank.
""",
    'room/nightstand/top_drawer/stuff.txt': """\
The top drawer of your nightstand has a mix of stuff in it. A comb, an
old brush (not your favorite but somehow still around), some hair ties,
some loose change (not many opportunities to use it these days) and a few
postcards from your friend who's studying abroad that you wanted to hang
onto but didn't have a better place for.
""",

    'room/trashcan/trash.txt': """\
Snack wrappers, stray hairs, and dusty paper towels have all been
discarded here.
""",
}

SOLAR_LAYOUT = {
    'solar_system/Sol.txt': """\
Sol is our solar system's sun, and is about 109 times the width of the
earth. The core reaches 15 million °C, which is a pretty ridiculous
number if you think about it.

https://solarsystem.nasa.gov/solar-system/sun/in-depth/
""",
    'solar_system/inner_planets/Mercury.txt': """\
About 1/3 the radius of Earth and orbiting just 0.4 AU from Sol, Mercury
is scorching hot on the sunward side and freezing on the other side,
reaching 430°C on the day side and -180°C on the night side.

https://solarsystem.nasa.gov/planets/planets/mercury/in-depth/
""",
    'solar_system/inner_planets/Venus.txt': """\
Almost the same size as Earth and orbiting 0.7 AU from Sol, Venus is even
hotter than Mercury thanks to its dense clouds, reaching 475°C.

https://solarsystem.nasa.gov/planets/planets/venus/in-depth/
""",
    'solar_system/inner_planets/Earth.txt': """\
Earth is exactly the same size as Earth, and orbits 1 AU from Sol. It's a
pretty cool place.

https://solarsystem.nasa.gov/planets/planets/earth/in-depth/
""",
    'solar_system/inner_planets/Mars.txt': """\
Mars is about half the size of Earth, and orbits 1.5 AU from Sol. It's
rocky and dry, but has an atmosphere and even ice and seasonal water
flows.

https://solarsystem.nasa.gov/planets/planets/mars/in-depth/
""",
    'solar_system/inner_planets/Ceres.txt': """\
Ceres was originally classified as an asteroid, but in 2006 was
reclassified as a dwarf planet, since it's 1/13th the radius of Earth.
Unlike the other dwarf planets which orbit out beyond Neptune, it orbits
just 2.8 AU from Sol, in the asteroid belt.

https://solarsystem.nasa.gov/planets/dwarf-planets/ceres/in-depth/
""",
    'solar_system/outer_planets/Jupiter.txt': """\
Jupiter is about 11 times as wide as Earth, and orbits 5.2 AU from Sol,
beyond the asteroid belt. It's the largest planet in the solar system,
and is a gas giant.

https://solarsystem.nasa.gov/planets/planets/jupiter/in-depth/
""",
    'solar_system/outer_planets/Saturn.txt': """\
Saturn orbits 9.5 AU from Sol and is 9 times as wide as Earth. It's well
known for its beautiful rings and like Jupiter, it's a gas giant.

https://solarsystem.nasa.gov/planets/planets/saturn/in-depth/
""",
    'solar_system/outer_planets/Uranus.txt': """\
Uranus is 4 times the size of Earth, and orbits 19.8 AU from Sol. It's an
"ice giant" rather than a "gas giant" because it's so far from the sun.

https://solarsystem.nasa.gov/planets/planets/uranus/in-depth/
""",
    'solar_system/outer_planets/Neptune.txt': """\
Neptune is another ice giant, and like Uranus, it's about 4 times the
size of Earth. It orbits 30 AU from Sol. It doesn't have rings like
Saturn, but it does have a beautiful blue color.

https://solarsystem.nasa.gov/planets/planets/neptune/in-depth/
""",
    'solar_system/distant_planets/Pluto.txt': """\
Once classified as a planet, Pluto is now termed a "dwarf planet." It's
about 1/6 as wide as earth, and has an strongly elliptical orbit between
30 and 49.3 AU from Sol.

https://solarsystem.nasa.gov/planets/dwarf-planets/pluto/in-depth/
""",
    'solar_system/distant_planets/Eris.txt': """\
A dwarf planet about the same size as Pluto, discovered in 2005. Its
radius is about 1/5 that of Earth, and it orbits about 68 AU from Sol.

https://solarsystem.nasa.gov/planets/dwarf-planets/eris/in-depth/
""",
    'solar_system/distant_planets/Haumea.txt': """\
A dwarf planet discovered in 2003 about 1/14th the radius of Earth,
orbiting in the Kuiper belt around 43 AU from Sol.

https://solarsystem.nasa.gov/planets/dwarf-planets/haumea/in-depth/
""",
    'solar_system/distant_planets/Makemake.txt': """\
Another dwarf planet discovered around the same time as Eris in 2005 and
not too much smaller than Pluto (it's 1/9 the radius of Earth). It
orbits 45.8 AU from Sol.

https://solarsystem.nasa.gov/planets/dwarf-planets/makemake/in-depth/
""",
    'solar_system/distant_planets/PlanetX.txt': """\
Hypothesized to exist but not yet actually discovered, Planet 9 would be
a larger-than-Earth planet hanging out somewhere between 250-1500 AU
from Sol.

https://solarsystem.nasa.gov/planets/hypothetical-planet-x/in-depth/
""",
}


def createDirsFromLayout(layout):
    """
    Given a layout dictionary which maps full paths of files to file
    contents, creates all necessary directories and puts the specified
    contents into each listed file.
    """
    for path, contents in layout.items():
        if not os.path.exists(path):
            dirname, filename = os.path.split(path)
            # Ensure directory exists:
            os.makedirs(dirname, exist_ok=True)
            # Write file
            with open(path, 'w') as fileWriter:
                fileWriter.write(contents)


def default():
    """
    Default setup steps.
    """
    createDirsFromLayout(ROOM_LAYOUT)
    createDirsFromLayout(SOLAR_LAYOUT)
